==> haskell-mime-types-0.1.0.7-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-mime-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mime-types
version: 0.1.0.7
id: mime-types-0.1.0.7-LUz1fzcauM82P0JAicK9l4
key: mime-types-0.1.0.7-LUz1fzcauM82P0JAicK9l4
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/yesodweb/wai
synopsis: Basic mime-type handling types and functions
description:
    API docs and the README are available at <http://www.stackage.org/package/mime-types>.
category: Web
abi: 4b037b274a675339ca568d385933d1c6
exposed: True
exposed-modules:
    Network.Mime
import-dirs: /usr/lib/ghc-8.4.3/site-local/mime-types-0.1.0.7
library-dirs: /usr/lib/ghc-8.4.3/site-local/mime-types-0.1.0.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/mime-types-0.1.0.7
hs-libraries: HSmime-types-0.1.0.7-LUz1fzcauM82P0JAicK9l4
depends:
    base-4.11.1.0 containers-0.5.11.0 text-1.2.3.0 bytestring-0.10.8.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
haddock-interfaces: /usr/share/doc/haskell-mime-types/html/mime-types.haddock
haddock-html: /usr/share/doc/haskell-mime-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mime-types-0.1.0.8-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-mime-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mime-types
version: 0.1.0.8
id: mime-types-0.1.0.8-9tF87HO5ShrGIShG8eldW4
key: mime-types-0.1.0.8-9tF87HO5ShrGIShG8eldW4
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/yesodweb/wai
synopsis: Basic mime-type handling types and functions
description:
    API docs and the README are available at <http://www.stackage.org/package/mime-types>.
category: Web
abi: 6260d9a08ca2b5415d71a41584891d7f
exposed: True
exposed-modules:
    Network.Mime
import-dirs: /usr/lib/ghc-8.4.3/site-local/mime-types-0.1.0.8
library-dirs: /usr/lib/ghc-8.4.3/site-local/mime-types-0.1.0.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/mime-types-0.1.0.8
hs-libraries: HSmime-types-0.1.0.8-9tF87HO5ShrGIShG8eldW4
depends:
    base-4.11.1.0 containers-0.5.11.0 text-1.2.3.0 bytestring-0.10.8.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
haddock-interfaces: /usr/share/doc/haskell-mime-types/html/mime-types.haddock
haddock-html: /usr/share/doc/haskell-mime-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
